@@ -3,9 +3,9 @@ package Meta::Grapher::Moose::Renderer::Graphviz;
 use strict;
 use warnings;
 use namespace::autoclean;
-use autodie qw( :all );
+use autodie;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use File::Temp qw( tempfile );
 use GraphViz2;
@@ -132,7 +132,7 @@ Meta::Grapher::Moose::Renderer::Graphviz - Render a Meta::Grapher::Moose as a gr
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
