@@ -3,9 +3,9 @@ package Meta::Grapher::Moose::Renderer::Plantuml;
 use strict;
 use warnings;
 use namespace::autoclean;
-use autodie qw( :all );
+use autodie;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 use IPC::Run3;
 use Meta::Grapher::Moose::Constants qw( CLASS ROLE P_ROLE ANON_ROLE );
@@ -181,7 +181,7 @@ Meta::Grapher::Moose::Renderer::Plantuml - Render a Meta::Grapher::Moose as a gr
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 SYNOPSIS
 
