@@ -3,8 +3,16 @@ use namespace::autoclean;
 use Moose::Role;
 
 ## no critic (ControlStructures/ProhibitYadaOperator)
-sub play_best_song_in_the_world {...}
-sub teach_school_of_rock        {...}
-sub get_dragon_scroll           {...}
+sub play_best_song_in_the_world {
+    return;
+}
+
+sub teach_school_of_rock {
+    return;
+}
+
+sub get_dragon_scroll {
+    return;
+}
 
 1;
