@@ -5,6 +5,8 @@ use Moose::Role;
 has actor_factory => ( is => 'ro' );
 
 ## no critic (ControlStructures::ProhibitYadaOperator)
-sub get_actor_for_character {...}
+sub get_actor_for_character {
+    return;
+}
 
 1;
